window.Gleam.initSearch([{"doc":"gpxb","title":"gpxb","content":"# gpxb\n\nA tiny GPX builder for Gleam.\n\n[![Package Version](https://img.shields.io/hexpm/v/gpxb)](https://hex.pm/packages/gpxb)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gpxb/)\n\n```sh\ngleam add gpxb@1\n```\n```gleam\nimport gpxb.{Gpx, Waypoint, Coordinate}\nimport gleam/option.{Some, None}\nimport gleam/string_builder\n\npub fn main() {\n  Gpx(\n    metadata: None,\n    waypoints: [\n      Waypoint(\n        coordinate: Coordinate(latitude: 51.53845, longitude: 0.14236),\n        name: Some(&quot;Mother Black Cap&quot;),\n        description: None,\n        time: None,\n      ),\n    ],\n    routes: [],\n    tracks: [],\n  )\n  |&gt; gpxb.render \n  |&gt; string_builder.to_string\n  |&gt; io.println\n}\n```\n\n```xml\n&lt;?xml version=&quot;1.0&quot; encoding=&quot;UTF-8&quot;?&gt;\n&lt;gpx version=&quot;1.1&quot; creator=&quot;gleam-gpxb&quot; xmlns=&quot;http://www.topografix.com/GPX/1/1&quot;&gt;\n  &lt;wpt latitude=&quot;51.53845&quot; longitude=&quot;0.14236&quot;&gt;\n    &lt;name&gt;Mother Black Cap&lt;/name&gt;\n  &lt;/wpt&gt;\n&lt;/gpx&gt;\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gpxb&gt;.\n","url":"index.html"},{"doc":"gpxb","title":"Coordinate","content":"pub type Coordinate {\n  Coordinate(latitude: Float, longitude: Float)\n}\n\nCoordinate(latitude: Float, longitude: Float)\n\nlatitude\n&lt;p&gt;The latitude of the point. Decimal degrees, WGS84 datum.&lt;/p&gt;\n&lt;p&gt;-90.0 &amp;lt;= value &amp;lt;= 90.0&lt;/p&gt;\n\nlongitude\n&lt;p&gt;The longitude of the point. Decimal degrees, WGS84 datum.&lt;/p&gt;\n&lt;p&gt;-180.0 &amp;lt;= value &amp;lt; 180.0&lt;/p&gt;\n\nSynonyms:\ngpxb.Coordinate\ngpxb Coordinate","url":"gpxb.html#Coordinate"},{"doc":"gpxb","title":"Gpx","content":"pub type Gpx {\n  Gpx(\n    metadata: Option(Metadata),\n    waypoints: List(Waypoint),\n    routes: List(Route),\n    tracks: List(Track),\n  )\n}\n\nGpx(\n  metadata: Option(Metadata),\n  waypoints: List(Waypoint),\n  routes: List(Route),\n  tracks: List(Track),\n)\n\n\nSynonyms:\ngpxb.Gpx\ngpxb Gpx","url":"gpxb.html#Gpx"},{"doc":"gpxb","title":"Link","content":"pub type Link {\n  Link(href: String, text: Option(String), type_: Option(String))\n}\n A link to an external resource (Web page, digital photo, video clip, etc)\n with additional information.\nLink(href: String, text: Option(String), type_: Option(String))\n\n\nSynonyms:\ngpxb.Link\ngpxb Link","url":"gpxb.html#Link"},{"doc":"gpxb","title":"Metadata","content":"pub type Metadata {\n  Metadata(\n    name: Option(String),\n    description: Option(String),\n    author: Option(Person),\n  )\n}\n Information about the GPX file, author, and copyright restrictions goes in\n the metadata section. Providing rich, meaningful information about your GPX\n files allows others to search for and use your GPS data.\nMetadata(\n  name: Option(String),\n  description: Option(String),\n  author: Option(Person),\n)\n\n\nSynonyms:\ngpxb.Metadata\ngpxb Metadata","url":"gpxb.html#Metadata"},{"doc":"gpxb","title":"Person","content":"pub type Person {\n  Person(\n    name: Option(String),\n    email: Option(String),\n    link: Option(Link),\n  )\n}\n A person or organization.\nPerson(\n  name: Option(String),\n  email: Option(String),\n  link: Option(Link),\n)\n\n\nSynonyms:\ngpxb.Person\ngpxb Person","url":"gpxb.html#Person"},{"doc":"gpxb","title":"Route","content":"pub type Route {\n  Route(\n    name: Option(String),\n    description: Option(String),\n    source: Option(String),\n    links: List(Link),\n    waypoints: List(Waypoint),\n  )\n}\n An ordered series of waypoints representing a suggested series of turn points\n leading to a destination. \nRoute(\n  name: Option(String),\n  description: Option(String),\n  source: Option(String),\n  links: List(Link),\n  waypoints: List(Waypoint),\n)\n\nsource\n&lt;p&gt;Source of data. Included to give user some idea of reliability and\naccuracy of data.&lt;/p&gt;\n\nlinks\n&lt;p&gt;Links to external information about the route.&lt;/p&gt;\n\nwaypoints\n&lt;p&gt;The points of the route&lt;/p&gt;\n\nSynonyms:\ngpxb.Route\ngpxb Route","url":"gpxb.html#Route"},{"doc":"gpxb","title":"Time","content":"pub type Time {\n  Time(\n    year: Int,\n    month: Int,\n    day: Int,\n    hour: Int,\n    minute: Int,\n    second: Int,\n    millisecond: Int,\n  )\n}\n Date and time in are in Univeral Coordinated Time (UTC), not local time!\n\n Conforms to ISO 8601 specification for date/time representation. Fractional\n seconds are allowed for millisecond timing in tracklogs.\n\nTime(\n  year: Int,\n  month: Int,\n  day: Int,\n  hour: Int,\n  minute: Int,\n  second: Int,\n  millisecond: Int,\n)\n\n\nSynonyms:\ngpxb.Time\ngpxb Time","url":"gpxb.html#Time"},{"doc":"gpxb","title":"Track","content":"pub type Track {\n  Track(\n    name: Option(String),\n    description: Option(String),\n    source: Option(String),\n    links: List(Link),\n    segments: List(TrackSegment),\n  )\n}\n An ordered series of points describing a path that has been taken.\nTrack(\n  name: Option(String),\n  description: Option(String),\n  source: Option(String),\n  links: List(Link),\n  segments: List(TrackSegment),\n)\n\nsource\n&lt;p&gt;Source of data. Included to give user some idea of reliability and\naccuracy of data.&lt;/p&gt;\n\nlinks\n&lt;p&gt;Links to external information about the route.&lt;/p&gt;\n\nSynonyms:\ngpxb.Track\ngpxb Track","url":"gpxb.html#Track"},{"doc":"gpxb","title":"TrackSegment","content":"pub type TrackSegment {\n  TrackSegment(waypoints: List(Waypoint))\n}\n A Track Segment holds a list of Track Points which are logically connected\n in order. To represent a single GPS track where GPS reception was lost, or\n the GPS receiver was turned off, start a new `TrackSegment` for each\n continuous span of track data.\nTrackSegment(waypoints: List(Waypoint))\n\n\nSynonyms:\ngpxb.TrackSegment\ngpxb TrackSegment","url":"gpxb.html#TrackSegment"},{"doc":"gpxb","title":"Waypoint","content":"pub type Waypoint {\n  Waypoint(\n    coordinate: Coordinate,\n    name: Option(String),\n    description: Option(String),\n    time: Option(Time),\n  )\n}\n A waypoint, point of interest, or named feature on a map.\nWaypoint(\n  coordinate: Coordinate,\n  name: Option(String),\n  description: Option(String),\n  time: Option(Time),\n)\n\ntime\n&lt;p&gt;Creation/modification timestamp for element.&lt;/p&gt;\n\nSynonyms:\ngpxb.Waypoint\ngpxb Waypoint","url":"gpxb.html#Waypoint"},{"doc":"gpxb","title":"render","content":"pub fn render(gpx: Gpx) -&gt; StringTree\n\nSynonyms:\ngpxb.render\ngpxb render","url":"gpxb.html#render"},{"doc":"gpxb","title":"gpxb","content":"","url":"gpxb.html"}]);